vdoc.api.routes package | vdoc 0.19.0 documentation

Skip to content

# vdoc.api.routes package

## Submodules

## vdoc.api.routes.plugins module

Contains all plugin routes.

vdoc.api.routes.plugins.get_router()

  Dynamically configures the router and loads all plugin routes.

  Return type:

    `APIRouter`

  Returns:

    The FastAPI router instance.

## vdoc.api.routes.project_categories module

Contains all project category related REST API routes.

vdoc.api.routes.project_categories.list_project_categories()

  Lists all available project categories.

  Return type:

    `list`[`ProjectCategory`]

  Returns:

    A list of all available project categories.

## vdoc.api.routes.projects module

Contains all projects related REST API routes.

vdoc.api.routes.projects.get_project_versions(name, version)

  Returns the requested project version.

  Parameters:

    - name (`str`) – The name of the project.

    - version (`str`) – The requested version.

  Return type:

    `str`

  Returns:

    The requested project version.

vdoc.api.routes.projects.list_project_versions(name)

  Lists all versions of a project.

  Parameters:

    name (`str`) – The name of the project.

  Return type:

    `list`[`str`]

  Returns:

    A list of all versions of a project.

vdoc.api.routes.projects.list_projects()

  Lists all available projects.

  Return type:

    `list`[`Project`]

  Returns:

    A list of all available projects.

vdoc.api.routes.projects.upload_project_version(name, version, file, _)

  Accepts and processes an uploaded project documentation.

  Parameters:

    - name (`str`) – The project name.

    - version (`str`) – The project version.

    - file (`UploadFile`) – The documentation zip file.

  Return type:

    `JSONResponse`

  Returns:

    A message that the documentation has been uploaded successfully.

## vdoc.api.routes.version module

Contains the version REST API routes.

vdoc.api.routes.version.get_app_version_route()

  Returns the version of the app.

  Return type:

    `str`

  Returns:

    The app version.

## Module contents

Contains all REST API routes.

vdoc.api.dependencies package
vdoc.cli package